Documentation
¶
Index ¶
- Variables
- type Subject
- func (x *Subject) GetInstanceName() string
- func (x *Subject) GetName() string
- func (*Subject) ProtoMessage()
- func (x *Subject) ProtoReflect() protoreflect.Message
- func (x *Subject) Reset()
- func (x *Subject) SetInstanceName(v string)
- func (x *Subject) SetName(v string)
- func (x *Subject) String() string
- type Subject_builder
Constants ¶
This section is empty.
Variables ¶
var ( // subject identifies Confluent Schema Registry subjects whose schema is // defined by the containing message. // // repeated buf.confluent.v1.Subject subject = 1158; E_Subject = &file_buf_confluent_v1_extensions_proto_extTypes[0] )
Extension fields to descriptorpb.MessageOptions.
var File_buf_confluent_v1_extensions_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Subject ¶
type Subject struct {
// instance_name is the user-specified name for the Confluent Schema Registry
// instance within the BSR. Instances are managed within Admin Settings in the BSR.
InstanceName string `protobuf:"bytes,1,opt,name=instance_name,json=instanceName,proto3" json:"instance_name,omitempty"`
// name is the subject's name, determined by the subject naming strategy. See
// the Confluent documentation for more details:
// https://docs.confluent.io/platform/current/schema-registry/fundamentals/serdes-develop/index.html#subject-name-strategy
//
// The default subject name strategy is TopicNameStrategy, which appends
// either '-key' or '-value' to a Kafka topic's name to create the subject
// name.
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
Subject declares a unique mapping between a protobuf Message and a subject name with an instance of the Confluent Schema Registry integration in the BSR.
For more details on the Confluent Schema Registry model, see: https://docs.confluent.io/platform/current/schema-registry/fundamentals/index.html#schemas-subjects-and-topics
func (*Subject) ProtoReflect ¶
func (x *Subject) ProtoReflect() protoreflect.Message
type Subject_builder ¶
type Subject_builder struct {
// instance_name is the user-specified name for the Confluent Schema Registry
// instance within the BSR. Instances are managed within Admin Settings in the BSR.
InstanceName string
// name is the subject's name, determined by the subject naming strategy. See
// the Confluent documentation for more details:
// https://docs.confluent.io/platform/current/schema-registry/fundamentals/serdes-develop/index.html#subject-name-strategy
//
// The default subject name strategy is TopicNameStrategy, which appends
// either '-key' or '-value' to a Kafka topic's name to create the subject
// name.
Name string
// contains filtered or unexported fields
}
func (Subject_builder) Build ¶
func (b0 Subject_builder) Build() *Subject
Source Files
¶
- extensions.pb.go
Click to show internal directories.
Click to hide internal directories.