Documentation
¶
Index ¶
- Variables
- type EmailUpdated
- func (x *EmailUpdated) GetId() string
- func (x *EmailUpdated) GetNewEmailAddress() string
- func (x *EmailUpdated) GetOldEmailAddress() string
- func (*EmailUpdated) ProtoMessage()
- func (x *EmailUpdated) ProtoReflect() protoreflect.Message
- func (x *EmailUpdated) Reset()
- func (x *EmailUpdated) SetId(v string)
- func (x *EmailUpdated) SetNewEmailAddress(v string)
- func (x *EmailUpdated) SetOldEmailAddress(v string)
- func (x *EmailUpdated) String() string
- type EmailUpdated_builder
Constants ¶
This section is empty.
Variables ¶
var File_bufstream_demo_v1_demo_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type EmailUpdated ¶
type EmailUpdated struct {
// The ID of the user associated with this email address update.
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// The old email address.
OldEmailAddress string `protobuf:"bytes,2,opt,name=old_email_address,json=oldEmailAddress,proto3" json:"old_email_address,omitempty"`
// The new email address.
NewEmailAddress string `protobuf:"bytes,3,opt,name=new_email_address,json=newEmailAddress,proto3" json:"new_email_address,omitempty"`
// contains filtered or unexported fields
}
An event where an email address was updated for a given user.
This represents the schema of data sent to the `email-updated-value` subject.
func (*EmailUpdated) GetId ¶
func (x *EmailUpdated) GetId() string
func (*EmailUpdated) GetNewEmailAddress ¶
func (x *EmailUpdated) GetNewEmailAddress() string
func (*EmailUpdated) GetOldEmailAddress ¶
func (x *EmailUpdated) GetOldEmailAddress() string
func (*EmailUpdated) ProtoMessage ¶
func (*EmailUpdated) ProtoMessage()
func (*EmailUpdated) ProtoReflect ¶
func (x *EmailUpdated) ProtoReflect() protoreflect.Message
func (*EmailUpdated) Reset ¶
func (x *EmailUpdated) Reset()
func (*EmailUpdated) SetId ¶
func (x *EmailUpdated) SetId(v string)
func (*EmailUpdated) SetNewEmailAddress ¶
func (x *EmailUpdated) SetNewEmailAddress(v string)
func (*EmailUpdated) SetOldEmailAddress ¶
func (x *EmailUpdated) SetOldEmailAddress(v string)
func (*EmailUpdated) String ¶
func (x *EmailUpdated) String() string
type EmailUpdated_builder ¶
type EmailUpdated_builder struct {
// The ID of the user associated with this email address update.
Id string
// The old email address.
OldEmailAddress string
// The new email address.
NewEmailAddress string
// contains filtered or unexported fields
}
func (EmailUpdated_builder) Build ¶
func (b0 EmailUpdated_builder) Build() *EmailUpdated
Source Files
¶
- demo.pb.go
Click to show internal directories.
Click to hide internal directories.